@@ -312,6 +312,7 @@ class FileSet(DataType):
     # type to None for any base classes that should not correspond to a MIME or MIME-like
     # type.
     iana_mime = None
+    ext = ""
 
     # Store converters registered by @converter decorator that convert to FileSet
     # NB: each class will have its own version of this dictionary
@@ -336,7 +337,7 @@ class FileSet(DataType):
             missing_str = "\n".join(str(p) for p in missing)
             all_str = "\n".join(str(p) for p in fspaths)
             msg = (
-                f"The following file system paths provided to {self} do not "
+                f"The following file system paths provided to {type(self)} do not "
                 f"exist:\n{missing_str}\n\nFrom full list:\n{all_str}"
             )
             present_parents = set()
@@ -345,8 +346,10 @@ class FileSet(DataType):
                     if fspath.parent.exists():
                         present_parents.add(fspath.parent)
             for parent in present_parents:
-                msg += f"\n\nFiles in the present parent directory '{str(fspath.parent)}' are:\n"
-                msg += "\n".join(str(p) for p in fspath.parent.iterdir())
+                msg += (
+                    f"\n\nFiles in the present parent directory '{str(parent)}' are:\n"
+                )
+                msg += "\n".join(str(p) for p in parent.iterdir())
             raise FileNotFoundError(msg)
 
     def __iter__(self):
@@ -408,12 +411,19 @@ class FileSet(DataType):
         """Returns all fspaths that are required for the format"""
         required = set()
         for prop_name in self.required_properties():
-            try:
-                prop = Path(getattr(self, prop_name))
-            except TypeError:
-                continue
-            if prop in self.fspaths:
-                required.add(prop)
+            prop = getattr(self, prop_name)
+            paths = []
+            if hasattr(prop, "required_paths"):
+                paths = prop.required_paths()
+            elif isinstance(prop, os.PathLike):
+                paths = [Path(prop)]
+            elif isinstance(prop, ty.Iterable):
+                for p in prop:
+                    if isinstance(p, os.PathLike):
+                        paths.append(Path(p))
+            for path in paths:
+                if path in self.fspaths:
+                    required.add(path)
         return required
 
     def trim_paths(self):
@@ -483,7 +493,10 @@ class FileSet(DataType):
         else:
             fspaths_to_copy = self.fspaths
         for fspath in fspaths_to_copy:
-            new_fname = stem + ".".join(fspath.suffixes) if stem else fspath.name
+            if stem:
+                new_fname = stem + "".join(fspath.suffixes)
+            else:
+                new_fname = fspath.name
             new_path = dest_dir / new_fname
             if fspath.is_dir():
                 copy_dir(fspath, new_path)
@@ -622,8 +635,8 @@ class FileSet(DataType):
             return None
         converters = (
             cls.get_converters_dict()
-        )  # triggers loading of standard converters
-        # Ensure converters from source format is loaded
+        )  # triggers loading of standard converters for target format
+        # Ensure standard converters from source format are loaded
         source_format.import_standard_converters()
         try:
             unqualified = source_format.unqualified
@@ -632,8 +645,10 @@ class FileSet(DataType):
         else:
             unqualified.import_standard_converters()
         try:
-            converter, conv_kwargs = converters[source_format]
+            converter_tuple = converters[source_format]
         except KeyError:
+            # If no direct mapping check for mapping from source super types and wildcard
+            # matches
             available_converters = cls.get_converter_tuples(source_format)
             if len(available_converters) > 1:
                 available_str = "\n".join(
@@ -648,8 +663,12 @@ class FileSet(DataType):
                     f"Could not find converter between '{source_format.mime_like}' and "
                     f"'{cls.mime_like}' formats"
                 ) from None
-            converter, conv_kwargs = available_converters[0]
+            converter_tuple = available_converters[0]
+            # Store mapping for future reference
+            converters[source_format] = converter_tuple
+        converter, conv_kwargs = converter_tuple
         if kwargs:
+            # Merge kwargs provided to get_conveter with stored kwargs
             conv_kwargs = copy(conv_kwargs)
             conv_kwargs.update(kwargs)
         return converter(name=name, **conv_kwargs)
@@ -835,12 +854,15 @@ class FileSet(DataType):
                 relative_to /= os.path.commonprefix(
                     [p.name for p in self.fspaths]
                 ).rstrip(".")
+        relative_to = str(relative_to)
+        if Path(relative_to).is_dir() and not relative_to.endswith(os.path.sep):
+            relative_to += os.path.sep
         if crypto is None:
             crypto = hashlib.sha256
 
         file_hashes = {}
         for key, fspath in sorted(
-            ((str(p)[len(str(relative_to)) :], p) for p in self.fspaths),
+            ((str(p)[len(relative_to) :], p) for p in self.fspaths),
             key=itemgetter(0),
         ):
             if fspath.is_file():
