@@ -105,7 +105,9 @@ def fspaths_converter(
     ]
 ):
     """Ensures fs-paths are a set of pathlib.Path"""
-    if isinstance(fspaths, (str, os.PathLike, bytes)):
+    if isinstance(fspaths, (str, os.PathLike, bytes)) and not isinstance(
+        fspaths, fileformats.core.FileSet
+    ):
         fspaths = [fspaths]
     return frozenset(Path(p).absolute() for p in fspaths)
 
@@ -212,7 +214,7 @@ def hash_dir(
         for filename in filenames:
             if ignore_hidden_files and filename.startswith("."):
                 continue
-            file_hashes[str(dpath.relative_to(relative_to))] = hash_file(
+            file_hashes[str((dpath / filename).relative_to(relative_to))] = hash_file(
                 dpath / filename, crypto=crypto, chunk_len=chunk_len
             )
     return file_hashes
